﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Microsoft.WindowsCE.Forms;
using Opticon.Bcrctl;

namespace BCRCTL_Sample
{
    public partial class Form1 : Form
    {
        Opticon.Bcrctl.BarcodeReader BCR;
        Opticon.Bcrctl.BarcodeDecoder BCD;

        ListView listView1;
        ListViewItem[] CodeID;

        public Form1()
        {
            InitializeComponent();

            BCR = new BarcodeReader();
            BCD = new BarcodeDecoder();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // BarcodeReader Setting Page Init
            if (BCR.PowerOn)
                checkBox_PowerOn.Checked = true;
            else
                checkBox_PowerOn.Checked = false;

            switch (BCR.TriggerKeySetting)
            {
                case TriggerKey.DISABLED:
                    comboBox_TriggerKeySetting.SelectedIndex = 0;
                    break;
                case TriggerKey.SIDE:
                    comboBox_TriggerKeySetting.SelectedIndex = 1;
                    break;
                case TriggerKey.CENTER:
                    comboBox_TriggerKeySetting.SelectedIndex = 2;
                    break;
                case TriggerKey.BOTH:
                    comboBox_TriggerKeySetting.SelectedIndex = 3;
                    break;
            }

            switch (BCR.OutputMode)
            {
                case DataOutput.BUFFER:
                    comboBox_OutputMode.SelectedIndex = 0;
                    break;
                case DataOutput.KEYCODE:
                    comboBox_OutputMode.SelectedIndex = 1;
                    break;
                case DataOutput.CLIPBOARD:
                    comboBox_OutputMode.SelectedIndex = 2;
                    break;
            }

            switch (BCR.BuzzerVolume)
            {
                case Volume.MUTE:
                    comboBox_BuzzerVolume.SelectedIndex = 0;
                    break;
                case Volume.LOW:
                    comboBox_BuzzerVolume.SelectedIndex = 1;
                    break;
                case Volume.MIDDLE:
                    comboBox_BuzzerVolume.SelectedIndex = 2;
                    break;
                case Volume.HIGH:
                    comboBox_BuzzerVolume.SelectedIndex = 3;
                    break;
            }

            textBox_FilePath.Text = BCR.BeepFile.ToString();

            // Decoder Setting Page Init
            if (BCD.ReadMode == BCRReadMode.SINGLE)
                radioButton_SingleMode.Checked = true;
            else
                radioButton_MultipleMode.Checked = true;

            switch (BCD.ReadTime)
            {
                case BCRReadTime.ZERO_SEC:
                    comboBox_ReadTime.SelectedIndex = 0;
                    break;
                case BCRReadTime.ONE_SEC:
                    comboBox_ReadTime.SelectedIndex = 1;
                    break;
                case BCRReadTime.TWO_SEC:
                    comboBox_ReadTime.SelectedIndex = 2;
                    break;
                case BCRReadTime.THREE_SEC:
                    comboBox_ReadTime.SelectedIndex = 3;
                    break;
                case BCRReadTime.FOUR_SEC:
                    comboBox_ReadTime.SelectedIndex = 4;
                    break;
                case BCRReadTime.FIVE_SEC:
                    comboBox_ReadTime.SelectedIndex = 5;
                    break;
                case BCRReadTime.SIX_SEC:
                    comboBox_ReadTime.SelectedIndex = 6;
                    break;
                case BCRReadTime.SEVEN_SEC:
                    comboBox_ReadTime.SelectedIndex = 7;
                    break;
                case BCRReadTime.EIGHT_SEC:
                    comboBox_ReadTime.SelectedIndex = 8;
                    break;
                case BCRReadTime.NINE_SEC:
                    comboBox_ReadTime.SelectedIndex = 9;
                    break;
                case BCRReadTime.INDEFINITELY:
                    comboBox_ReadTime.SelectedIndex = 10;
                    break;
            }

            textBox_SuffixChar.Text = BCD.SuffixChar.ToString();

            switch (BCD.NegativeSymbol)
            { 
                case BCRNegativeSymbol.Positive:
                    comboBox_NegativeBarcode.SelectedIndex = 0;
                    break;
                case BCRNegativeSymbol.Negative:
                    comboBox_NegativeBarcode.SelectedIndex = 1;
                    break;
                case BCRNegativeSymbol.Both:
                    comboBox_NegativeBarcode.SelectedIndex = 2;
                    break;
            }

            // Readable Codes ListView Init
            ListViewInit();

        }

        private void ListViewInit()
        {
            // Create a new ListView control.
            listView1 = new ListView();
            listView1.Bounds = new Rectangle(8,110,210,95);

            // Set the view to show details.
            listView1.View = View.Details;
            
            // Display check boxes.
            listView1.CheckBoxes = true;
            // Select the item and subitems when selection is made.
            listView1.FullRowSelect = true;

            CodeID = new ListViewItem[4];
            long readableCode = BCD.ReadableCodes;

            CodeID[0] = new ListViewItem("UPC");
            listView1.Items.Add(CodeID[0]);
            if ((readableCode & (long)CodeList.UPC) != 0)
                CodeID[0].Checked = true;

            CodeID[1] = new ListViewItem("EAN(JAN)");
            listView1.Items.Add(CodeID[1]);
            if ((readableCode & (long)CodeList.EAN) != 0)
                CodeID[1].Checked = true;

            CodeID[2] = new ListViewItem("DataMatrix(ECC200)");
            listView1.Items.Add(CodeID[2]);
            if ((readableCode & (long)CodeList.DataMatrixECC200) != 0)
                CodeID[2].Checked = true;

            CodeID[3] = new ListViewItem("QR Code");
            listView1.Items.Add(CodeID[3]);
            if ((readableCode & (long)CodeList.QRCode) != 0)
                CodeID[3].Checked = true;

            listView1.Columns.Add("Click here to fix Readable Codes", -2, HorizontalAlignment.Left);
            tabPage4.Controls.Add(listView1);
            listView1.ColumnClick += new ColumnClickEventHandler(listView1_ColumnClick);
        }

        #region General Setting Page Functions

        private void checkBox_PowerOn_CheckStateChanged(object sender, EventArgs e)
        {
            if (checkBox_PowerOn.Checked)
                BCR.PowerOn = true;
            else
                BCR.PowerOn = false;
        }

        private void comboBox_TriggerKeySetting_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (comboBox_TriggerKeySetting.SelectedIndex)
            {
                case 0:
                    BCR.TriggerKeySetting = TriggerKey.DISABLED;
                    break;
                case 1:
                    BCR.TriggerKeySetting = TriggerKey.SIDE;
                    break;
                case 2:
                    BCR.TriggerKeySetting = TriggerKey.CENTER;
                    break;
                case 3:
                    BCR.TriggerKeySetting = TriggerKey.BOTH;
                    break;
            }
        }

        private void comboBox_OutputMode_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (comboBox_OutputMode.SelectedIndex)
            {
                case 0:
                    BCR.OutputMode = DataOutput.BUFFER;
                    break;
                case 1:
                    BCR.OutputMode = DataOutput.KEYCODE;
                    break;
                case 2:
                    BCR.OutputMode = DataOutput.CLIPBOARD;
                    break;
            }
        }

        private void comboBox_BuzzerVolume_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (comboBox_BuzzerVolume.SelectedIndex)
            {
                case 0:
                    BCR.BuzzerVolume = Volume.MUTE;
                    break;
                case 1:
                    BCR.BuzzerVolume = Volume.LOW;
                    break;
                case 2:
                    BCR.BuzzerVolume = Volume.MIDDLE;
                    break;
                case 3:
                    BCR.BuzzerVolume = Volume.HIGH;
                    break;
            }
        }

        private void button_Browse_Click(object sender, EventArgs e)
        {
            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                string str;
                str = openFileDialog1.FileName.Substring(openFileDialog1.FileName.Length - 3);
                if (str == "wav")
                {
                    textBox_FilePath.Text = openFileDialog1.FileName;
                    BCR.BeepFile = textBox_FilePath.Text;
                }
                else
                    MessageBox.Show("It's an invalid file.");
            }
        }

        #endregion

        #region Decoder Setting Page Functions

        private void listView1_ColumnClick(object sender, ColumnClickEventArgs e)
        {
            long readableCode = BCD.ReadableCodes;

            if (CodeID[0].Checked)
                readableCode |= (long)CodeList.UPC;
            else
                readableCode &= ~(long)CodeList.UPC;

            if (CodeID[1].Checked)
                readableCode |= (long)CodeList.EAN;
            else
                readableCode &= ~(long)CodeList.EAN;

            if (CodeID[2].Checked)
                readableCode |= (long)CodeList.DataMatrixECC200;
            else
                readableCode &= ~(long)CodeList.DataMatrixECC200;

            if (CodeID[3].Checked)
                readableCode |= (long)CodeList.QRCode;
            else
                readableCode &= ~(long)CodeList.QRCode;

            BCD.ReadableCodes = readableCode;
        }

        private void radioButton_SingleMode_CheckedChanged(object sender, EventArgs e)
        {
            BCD.ReadMode = BCRReadMode.SINGLE;
        }

        private void radioButton_MultipleMode_CheckedChanged(object sender, EventArgs e)
        {
            BCD.ReadMode = BCRReadMode.MULTIPLE;
        }

        private void comboBox_ReadTime_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (comboBox_ReadTime.SelectedIndex)
            {
                case 0:
                    BCD.ReadTime = BCRReadTime.ZERO_SEC;
                    break;
                case 1:
                    BCD.ReadTime = BCRReadTime.ONE_SEC;
                    break;
                case 2:
                    BCD.ReadTime = BCRReadTime.TWO_SEC;
                    break;
                case 3:
                    BCD.ReadTime = BCRReadTime.THREE_SEC;
                    break;
                case 4:
                    BCD.ReadTime = BCRReadTime.FOUR_SEC;
                    break;
                case 5:
                    BCD.ReadTime = BCRReadTime.FIVE_SEC;
                    break;
                case 6:
                    BCD.ReadTime = BCRReadTime.SIX_SEC;
                    break;
                case 7:
                    BCD.ReadTime = BCRReadTime.SEVEN_SEC;
                    break;
                case 8:
                    BCD.ReadTime = BCRReadTime.EIGHT_SEC;
                    break;
                case 9:
                    BCD.ReadTime = BCRReadTime.NINE_SEC;
                    break;
                case 10:
                    BCD.ReadTime = BCRReadTime.INDEFINITELY;
                    break;
            }
        }

        private void textBox_SuffixChar_KeyDown(object sender, KeyEventArgs e)
        {
            if(e.KeyCode == Keys.Enter)
            {
                BCD.SuffixChar = uint.Parse(textBox_SuffixChar.Text.ToString());
            }
        }

        private void comboBox_NegativeBarcode_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (comboBox_NegativeBarcode.SelectedIndex)
            { 
                case 0:
                    BCD.NegativeSymbol = BCRNegativeSymbol.Positive;
                    break;
                case 1:
                    BCD.NegativeSymbol = BCRNegativeSymbol.Negative;
                    break;
                case 2:
                    BCD.NegativeSymbol = BCRNegativeSymbol.Both;
                    break;
            }
        }

        #endregion

    }
}